@@ -181,45 +181,35 @@ def test_returns_inner_dict():
     )
 
 
-def test_returns_inner_list():
+def test_returns_inner_value():
     assert parse_function_definition(
-        'def Foo() -> Single[List]: ...'
+        'def Foo() -> Single[Value]: ...'
     ) == FunctionDefinition(
         name='Foo',
         args=[],
         returns=ReturnValueDefinition(
             outer_format=ReturnValueOuterFormat.SINGLE,
-            inner_format=ReturnValueInnerFormat.LIST
+            inner_format=ReturnValueInnerFormat.VALUE
         )
     )
 
 
-def test_returns_inner_single():
-    assert parse_function_definition(
-        'def Foo() -> Single[Single]: ...'
-    ) == FunctionDefinition(
-        name='Foo',
-        args=[],
-        returns=ReturnValueDefinition(
-            outer_format=ReturnValueOuterFormat.SINGLE,
-            inner_format=ReturnValueInnerFormat.SINGLE
-        )
-    )
-
-
-def test_returns_inner_custom():
-    assert parse_function_definition(
-        'def Foo() -> Single[MyType]: ...'
-    ) == FunctionDefinition(
-        name='Foo',
-        args=[],
-        returns=ReturnValueDefinition(
-            outer_format=ReturnValueOuterFormat.SINGLE,
-            inner_format='MyType'
-        )
-    )
-
-
-def test_returns_invalid():
+def test_returns_invalid_outer():
     with pytest.raises(TypeError):
         parse_function_definition('def Foo() -> BadType[List]: ...')
+
+
+def test_returns_invalid_inner():
+    with pytest.raises(TypeError):
+        parse_function_definition('def Foo() -> List[BadType]: ...')
+
+
+@pytest.mark.xfail
+def test_accepts_complex_arg_annotations():
+    parse_function_definition('def Foo(arg: Tuple[str, int]) -> None: ...')
+
+
+@pytest.mark.xfail
+def test_accepts_complex_return_annotations():
+    parse_function_definition('def Foo() -> Single[Value[bool]]: ...')
+    parse_function_definition('def Foo() -> Single[Value[Tuple[str, int]]]: ...')
